/*
 * H2Connector.fx
 *
 * @author Dmitry Danileyko
 *
 * Created on 06.02.2010, 0:13:19
 */

package org.narsereg.jfxkeyper;

import java.sql.*;
import java.lang.*;

/**
 * @author narsereg
 */

public class H2Connector {
    var connector : Connection;
    var statement : Statement;
    public-init var baseName : String;

    init {
        dbConnect(baseName);
        dbCreateTables();
    }

    function dbCreateTables() {
        try {
            dbUpdate("CREATE TABLE IF NOT EXISTS PASS(ID INT AUTO_INCREMENT "
                "PRIMARY KEY, RESOURCE VARCHAR(255), USER VARCHAR(255), PASSWORD "
                "LONGVARCHAR(1024), TYPE VARCHAR(255), FOLDER VARCHAR(255), "
                "COMMENT LONGVARCHAR(1024), PICTURE VARCHAR(255));");
        } catch (e : SQLException) {
            println("dbCreateTables. SQLException: {e.toString()}");
            FX.exit();
        }
    }

    function dbConnect(dbName : String) {
        var str : String;
        str = __DIR__.substring(0, __DIR__.lastIndexOf("!"));
        str = str.substring(0, str.lastIndexOf("/", str.length()) + 1);
        str = str.substring(4, str.length());

        try {
            Class.forName("org.h2.Driver");
        } catch (e : ClassNotFoundException) {
            println("dbConnect. Unable to load Driver Class");
            FX.exit();
        };

        try {
            connector = DriverManager.getConnection("jdbc:h2:{str}{dbName}", "sa", "");
            statement = connector.createStatement(ResultSet.TYPE_SCROLL_INSENSITIVE, ResultSet.CONCUR_READ_ONLY);
        } catch (e : SQLException) {
            println("dbConnect. SQLException: {e.toString()}");
            FX.exit();
        }
    }

    public function dbDisconnect(){
        try {
            statement.close();
            connector.close();
        } catch (e : SQLException) {
            println("dbDisconnect. SQLException: {e.toString()}");
            FX.exit();
        }
    }

    public function dbExecute(query : String) : ResultSet{
        var rs : ResultSet;
        try {
            rs = statement.executeQuery(query);
        } catch (e : SQLException) {
            println("dbExecute. SQLException: {e.toString()}");
        }
        return rs;
    }

    public function dbUpdate(query : String) : Integer{
        var res : Integer;
        try {
            res = statement.executeUpdate(query);
        } catch (e : SQLException) {
            println("dbUpdate. SQLException: {e.toString()}");
        }
        return res;
    }

}
